==> nodejs_interop-0.5.0.tar.gz: test/node/os_test.dart <==
import 'dart:js';
import 'package:nodejs_interop/nodejs_interop.dart';
import 'package:test/test.dart';

/// Tests the features of the [OSModule] class.
void main() => group('OSModule', () {
  final isMacOS = context['process']['platform'] == 'darwin';
  final isWindows = context['process']['platform'] == 'win32';
  final os = loadLibrary<OSModule>('os');

  group('.EOL', () {
    test(r'should be "\r\n" on Windows and "\n" on other platforms', () {
      expect(os.EOL, equals(isWindows ? '\r\n' : '\n'));
    });
  });

  group('.arch()', () {
    test('should be "x86" or "x64" on test platforms', () {
      expect(os.arch(), anyOf(equals('x86'), equals('x64')));
    });
  });

  group('.cpus()', () {
    test('should not be empty', () {
      expect(os.cpus(), isNotEmpty);
    });
  });

  group('.endianness()', () {
    test('should be "LE" on test platforms', () {
      expect(os.endianness(), equals('LE'));
    });
  });

  group('.platform()', () {
    test('should be "darwin" on macOS, "win32" on Windows and "linux" on other platforms', () {
      expect(os.platform(), equals(isWindows ? 'win32' : (isMacOS ? 'darwin' : 'linux')));
    });
  });

  group('.tmpdir()', () {
    test(r'should be "C:\Windows\Temp" on Windows and "/tmp" on other platforms', () {
      expect(os.tmpdir(), equals(isWindows ? r'C:\Windows\Temp' : '/tmp'));
    });
  });

  group('.totalmem()', () {
    test('should be greater than the amount of free system memory', () {
      expect(os.totalmem(), greaterThan(os.freemem()));
    });
  });

  group('.type()', () {
    test('should be "Darwin" on macOS, "Windows_NT" on Windows and "Linux" on other platforms', () {
      expect(os.type(), equals(isWindows ? 'Windows_NT' : (isMacOS ? 'Darwin' : 'Linux')));
    });
  });
});

==> nodejs_interop-0.6.0.tar.gz: test/node/os_test.dart <==
import 'dart:js';
import 'package:nodejs_interop/nodejs_interop.dart';
import 'package:test/test.dart';

/// Tests the features of the [OSModule] class.
void main() => group('OSModule', () {
  final isMacOS = context['process']['platform'] == 'darwin';
  final isWindows = context['process']['platform'] == 'win32';
  final os = loadLibrary<OSModule>('os');

  group('.EOL', () {
    test(r'should be "\r\n" on Windows and "\n" on other platforms', () {
      expect(os.EOL, equals(isWindows ? '\r\n' : '\n'));
    });
  });

  group('.arch()', () {
    test('should be "x86" or "x64" on test platforms', () {
      expect(os.arch(), anyOf(equals('x86'), equals('x64')));
    });
  });

  group('.cpus()', () {
    test('should not be empty', () {
      expect(os.cpus(), isNotEmpty);
    });
  });

  group('.endianness()', () {
    test('should be "LE" on test platforms', () {
      expect(os.endianness(), equals('LE'));
    });
  });

  group('.platform()', () {
    test('should be "darwin" on macOS, "win32" on Windows and "linux" on other platforms', () {
      expect(os.platform(), equals(isWindows ? 'win32' : (isMacOS ? 'darwin' : 'linux')));
    });
  });

  group('.tmpdir()', () {
    test(r'should be "C:\Windows\Temp" on Windows and "/tmp" on other platforms', () {
      expect(os.tmpdir(), isWindows ? endsWith(r'\Temp') : equals('/tmp'));
    });
  });

  group('.totalmem()', () {
    test('should be greater than the amount of free system memory', () {
      expect(os.totalmem(), greaterThan(os.freemem()));
    });
  });

  group('.type()', () {
    test('should be "Darwin" on macOS, "Windows_NT" on Windows and "Linux" on other platforms', () {
      expect(os.type(), equals(isWindows ? 'Windows_NT' : (isMacOS ? 'Darwin' : 'Linux')));
    });
  });
});
